@@ -32,6 +32,7 @@
 defined('_JEXEC') or die('Restricted access');
 
 require_once(JPATH_ROOT . DS . 'components' . DS . 'com_collections' . DS . 'models' . DS . 'following' . DS . 'abstract.php');
+ximport('Hubzero_User_Profile');
 
 /**
  * Model class for following a member
@@ -39,36 +40,36 @@ require_once(JPATH_ROOT . DS . 'components' . DS . 'com_collections' . DS . 'mod
 class CollectionsModelFollowingMember extends CollectionsModelFollowingAbstract
 {
 	/**
-	 * \Hubzero\User\Profile
-	 *
+	 * Hubzero_User_Profile
+	 * 
 	 * @var object
 	 */
 	private $_obj = NULL;
 
 	/**
 	 * File path
-	 *
+	 * 
 	 * @var string
 	 */
 	private $_image = NULL;
 
 	/**
 	 * URL
-	 *
+	 * 
 	 * @var string
 	 */
 	private $_baselink = NULL;
 
 	/**
 	 * JDatabase
-	 *
+	 * 
 	 * @var object
 	 */
 	//private $_db = NULL;
 
 	/**
 	 * Constructor
-	 *
+	 * 
 	 * @param      integer $id Member ID
 	 * @return     void
 	 */
@@ -76,7 +77,7 @@ class CollectionsModelFollowingMember extends CollectionsModelFollowingAbstract
 	{
 		//$this->_db = JFactory::getDBO();
 
-		$this->_obj = \Hubzero\User\Profile::getInstance($oid);
+		$this->_obj = Hubzero_User_Profile::getInstance($oid);
 
 		$this->_baselink = 'index.php?option=com_members&id=' . $this->_obj->get('uidNumber') . '&active=collections';
 	}
@@ -94,12 +95,12 @@ class CollectionsModelFollowingMember extends CollectionsModelFollowingAbstract
 	{
 		static $instances;
 
-		if (!isset($instances))
+		if (!isset($instances)) 
 		{
 			$instances = array();
 		}
 
-		if (!isset($instances[$oid]))
+		if (!isset($instances[$oid])) 
 		{
 			$instances[$oid] = new CollectionsModelFollowingMember($oid);
 		}
@@ -116,7 +117,8 @@ class CollectionsModelFollowingMember extends CollectionsModelFollowingAbstract
 	{
 		if (!isset($this->_image))
 		{
-			$this->_image = \Hubzero\User\Profile\Helper::getMemberPhoto($this->_obj, 0);
+			ximport('Hubzero_User_Profile_Helper');
+			$this->_image = Hubzero_User_Profile_Helper::getMemberPhoto($this->_obj, 0);
 		}
 		return $this->_image;
 	}
