@@ -31,18 +31,18 @@
 // Check to ensure this file is included in Joomla!
 defined('_JEXEC') or die('Restricted access');
 
-$pathway = JFactory::getApplication()->getPathway();
+$pathway =& JFactory::getApplication()->getPathway();
 $pathway->addItem(
 	JText::_('New Pages'),
 	'index.php?option=' . $this->option . '&scope=' . $this->page->scope . '&pagename=Special:NewPages'
 );
 
-$jconfig = JFactory::getConfig();
-$juser = JFactory::getUser();
+$jconfig =& JFactory::getConfig();
+$juser =& JFactory::getUser();
 
 $dir = strtoupper(JRequest::getVar('dir', 'ASC'));
 
-$database = JFactory::getDBO();
+$database =& JFactory::getDBO();
 
 $where = '';
 $namespace = urldecode(JRequest::getVar('namespace', ''));
@@ -51,12 +51,12 @@ if ($namespace)
 	$where .= "AND LOWER(wp.pagename) LIKE '" . strtolower($namespace) . "%'";
 }
 
-$query = "SELECT COUNT(*)
-			FROM #__wiki_version AS wv
-			INNER JOIN #__wiki_page AS wp
-				ON wp.id = wv.pageid
-			WHERE wv.approved = 1
-				AND wp.scope = '{$this->page->scope}'
+$query = "SELECT COUNT(*) 
+			FROM #__wiki_version AS wv 
+			INNER JOIN #__wiki_page AS wp 
+				ON wp.id = wv.pageid 
+			WHERE wv.approved = 1 
+				AND wp.scope = '{$this->page->scope}' 
 				$where
 				AND wv.id = (SELECT MAX(wv2.id) FROM #__wiki_version AS wv2 WHERE wv2.pageid = wv.pageid)";
 
@@ -64,11 +64,11 @@ $database->setQuery($query);
 $total = $database->loadResult();
 
 $query = "SELECT wv.pageid, (CASE WHEN (wp.`title` IS NOT NULL AND wp.`title` !='') THEN wp.`title` ELSE wp.`pagename` END) AS `title`, wp.pagename, wp.scope, wp.group_cn, wp.access, wv.version, wv.created_by, wv.created
-			FROM #__wiki_version AS wv
-			INNER JOIN #__wiki_page AS wp
-				ON wp.id = wv.pageid
-			WHERE wv.approved = 1
-				AND wp.scope = '{$this->page->scope}'
+			FROM #__wiki_version AS wv 
+			INNER JOIN #__wiki_page AS wp 
+				ON wp.id = wv.pageid 
+			WHERE wv.approved = 1 
+				AND wp.scope = '{$this->page->scope}' 
 				$where
 				AND wv.id = (SELECT MAX(wv2.id) FROM #__wiki_version AS wv2 WHERE wv2.pageid = wv.pageid)
 			ORDER BY title $dir";
@@ -80,7 +80,7 @@ $rows = $database->loadObjectList();
 	<div class="wikipage">
 	<fieldset>
 		<legend><?php echo JText::_('Filter list'); ?></legend>
-
+		
 		<label for="field-namespace">
 			<?php echo JText::_('Namespace'); ?>
 			<select name="namespace" id="field-namespace">
@@ -89,12 +89,12 @@ $rows = $database->loadObjectList();
 				<option value="Template:"<?php if ($namespace == 'Template:') { echo ' selected="selected"'; } ?>>Template:</option>
 			</select>
 		</label>
-
+		
 		<input type="submit" value="<?php echo JText::_('Go'); ?>" />
 	</fieldset>
-
+	
 <?php
-if ($rows)
+if ($rows) 
 {
 	$dateFormat = '%d %b %Y';
 	$tz = 0;
@@ -132,7 +132,7 @@ if ($rows)
 					<h3><?php echo $index; ?></h3>
 					<ul>
 					<?php
-				}
+				} 
 				else if ($k == 0)
 				{
 					?>
@@ -151,7 +151,7 @@ if ($rows)
 			}
 			?>
 			</ul>
-		<?php
+		<?php 
 		}
 		?>
 		</div>
