@@ -32,6 +32,7 @@
 defined('_JEXEC') or die('Restricted access');
 
 jimport('joomla.event.plugin');
+jimport('Hubzero.Ldap');
 
 /**
  * User plugin for hub users
@@ -40,7 +41,7 @@ class plgUserLdap extends JPlugin
 {
 	/**
 	 * Constructor
-	 *
+	 * 
 	 * @param      object &$subject Event observer
 	 * @param      array  $config   Optional config values
 	 * @return     void
@@ -60,8 +61,8 @@ class plgUserLdap extends JPlugin
 	 */
 	public function onAfterStoreUser($user, $isnew, $succes, $msg)
 	{
-		//JFactory::getLogger()->debug("plgUserLdap::onAfterStoreUser(" . $user['id'] . ")");
-		\Hubzero\Utility\Ldap::syncUser($user['id']);
+		//Hubzero_Factory::getLogger()->logDebug("plgUserLdap::onAfterStoreUser(" . $user['id'] . ")");
+		Hubzero_Ldap::syncUser($user['id']);
 	}
 
 	/**
@@ -73,73 +74,73 @@ class plgUserLdap extends JPlugin
 	 */
 	public function onAfterDeleteUser($user, $succes, $msg)
 	{
-		//JFactory::getLogger()->debug("plgUserLdap::onAfterDeleteUser(" . $user['id'] . ")");
-		\Hubzero\Utility\Ldap::syncUser($user['id']);
+		//Hubzero_Factory::getLogger()->logDebug("plgUserLdap::onAfterDeleteUser(" . $user['id'] . ")");
+		Hubzero_Ldap::syncUser($user['id']);
 	}
-
+	
 	/**
 	 * Method is called after user data is stored in the database
 	 *
-	 * @param object holds the new profile data (\Hubzero\User\Profile)
+	 * @param object holds the new profile data (Hubzero_User_Profile)
 	 */
 	public function onAfterStoreProfile($user)
 	{
-		//JFactory::getLogger()->debug("plgUserLdap::onAfterStoreProfile(" . $user->get('uidNumber') . ")");
-		\Hubzero\Utility\Ldap::syncUser($user->get('uidNumber'));
+		//Hubzero_Factory::getLogger()->logDebug("plgUserLdap::onAfterStoreProfile(" . $user->get('uidNumber') . ")");
+		Hubzero_Ldap::syncUser($user->get('uidNumber'));
 	}
 
 	/**
 	 * Method is called after user data is deleted from the database
 	 *
-	 * @param object holds the new profile data (\Hubzero\User\Profile)
+	 * @param object holds the new profile data (Hubzero_User_Profile)
 	 */
 	public function onAfterDeleteProfile($user)
 	{
-		//JFactory::getLogger()->debug("plgUserLdap::onAfterDeleteProfile(" . $user->get('uidNumber') . ")");
-		\Hubzero\Utility\Ldap::syncUser($user->get('uidNumber'));
+		//Hubzero_Factory::getLogger()->logDebug("plgUserLdap::onAfterDeleteProfile(" . $user->get('uidNumber') . ")");
+		Hubzero_Ldap::syncUser($user->get('uidNumber'));
 	}
-
+	
 	/**
 	 * Method is called after password data is stored in the database
 	 *
-	 * @param object holds the new password data (\Hubzero\User\Password)
+	 * @param object holds the new password data (Hubzero_User_Password)
 	 */
 	public function onAfterStorePassword($user)
 	{
-		//JFactory::getLogger()->debug("plgUserLdap::onAfterStoreUser(" . $user->user_id . ")");
-		\Hubzero\Utility\Ldap::syncUser($user->user_id);
+		//Hubzero_Factory::getLogger()->logDebug("plgUserLdap::onAfterStoreUser(" . $user->user_id . ")");
+		Hubzero_Ldap::syncUser($user->user_id);
 	}
 
 	/**
 	 * Method is called after password data is deleted from the database
 	 *
-	 * @param object holds the new password data (\Hubzero\User\Password)
+	 * @param object holds the new password data (Hubzero_User_Password)
 	 */
 	public function onAfterDeletePassword($user)
 	{
-		//JFactory::getLogger()->debug("plgUserLdap::onAfterDeleteUser(" . $user->user_id . ")");
-		\Hubzero\Utility\Ldap::syncUser($user->user_id);
+		//Hubzero_Factory::getLogger()->logDebug("plgUserLdap::onAfterDeleteUser(" . $user->user_id . ")");
+		Hubzero_Ldap::syncUser($user->user_id);
 	}
-
+	
 	/**
 	 * Method is called after group data is stored in the database
 	 *
-	 * @param object holds the new group data (\Hubzero\User\Group)
+	 * @param object holds the new group data (Hubzero_Group)
 	 */
 	public function onAfterStoreGroup($group)
 	{
-		//JFactory::getLogger()->debug("plgUserLdap::onAfterStoreGroup(" . $group->cn . ")");
-		\Hubzero\Utility\Ldap::syncGroup($group->cn);
+		//Hubzero_Factory::getLogger()->logDebug("plgUserLdap::onAfterStoreGroup(" . $group->cn . ")");
+		Hubzero_Ldap::syncGroup($group->cn);
 	}
-
+	
 	/**
 	 * Method is called after group data is deleted from the database
 	 *
-	 * @param object holds the new group data (\Hubzero\User\Group)
+	 * @param object holds the new group data (Hubzero_Group)
 	 */
 	public function onAfterDeleteGroup($group)
 	{
-		//JFactory::getLogger()->debug("onAfterDeleteGroup($group)");
-		\Hubzero\Utility\Ldap::syncGroup($group->cn);
-	}
+		//Hubzero_Factory::getLogger()->logDebug("onAfterDeleteGroup($group)");
+		Hubzero_Ldap::syncGroup($group->cn);
+	}	
 }
\ No newline at end of file
